@@ -146,6 +146,11 @@ extern char *CH_auth_command;
  */
 extern char *CH_address_type;
 
+/**
+ * Hint to show to users on what address to enter.
+ */
+extern char *CH_address_hint;
+
 /**
  * (external) base URL of this service.
  */
