@@ -448,7 +448,8 @@ CH_handler_solve (struct CH_HandlerContext *hc,
         GNUNET_free (url);
         return MHD_NO;
       }
-      TALER_MHD_add_global_headers (response);
+      TALER_MHD_add_global_headers (response,
+                                    false);
       GNUNET_break (MHD_YES ==
                     MHD_add_response_header (response,
                                              MHD_HTTP_HEADER_CONTENT_TYPE,
