@@ -234,7 +234,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
                      "authorization_code")) )
   {
     GNUNET_break_op (0);
-    return TALER_MHD_reply_with_oauth_error (
+    return CH_reply_with_oauth_error (
       hc->connection,
       MHD_HTTP_BAD_REQUEST,
       "unsupported_grant_type",
@@ -245,7 +245,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
   if (NULL == bc->code)
   {
     GNUNET_break_op (0);
-    return TALER_MHD_reply_with_oauth_error (
+    return CH_reply_with_oauth_error (
       hc->connection,
       MHD_HTTP_BAD_REQUEST,
       "invalid_request",
@@ -255,7 +255,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
   if (NULL == bc->client_secret)
   {
     GNUNET_break_op (0);
-    return TALER_MHD_reply_with_oauth_error (
+    return CH_reply_with_oauth_error (
       hc->connection,
       MHD_HTTP_BAD_REQUEST,
       "invalid_client",
@@ -265,7 +265,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
   if (NULL == bc->client_id)
   {
     GNUNET_break_op (0);
-    return TALER_MHD_reply_with_oauth_error (
+    return CH_reply_with_oauth_error (
       hc->connection,
       MHD_HTTP_BAD_REQUEST,
       "invalid_client",
@@ -275,7 +275,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
   if (NULL == bc->redirect_uri)
   {
     GNUNET_break_op (0);
-    return TALER_MHD_reply_with_oauth_error (
+    return CH_reply_with_oauth_error (
       hc->connection,
       MHD_HTTP_BAD_REQUEST,
       "invalid_request",
@@ -296,7 +296,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
                      &dummy))
     {
       GNUNET_break_op (0);
-      return TALER_MHD_reply_with_oauth_error (
+      return CH_reply_with_oauth_error (
         hc->connection,
         MHD_HTTP_BAD_REQUEST,
         "invalid_client",
@@ -323,7 +323,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
       return MHD_NO;
     case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
       GNUNET_break_op (0);
-      return TALER_MHD_reply_with_oauth_error (
+      return CH_reply_with_oauth_error (
         hc->connection,
         MHD_HTTP_UNAUTHORIZED,
         "invalid_client",
@@ -337,7 +337,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
                        bc->redirect_uri)) )
     {
       GNUNET_break_op (0);
-      return TALER_MHD_reply_with_oauth_error (
+      return CH_reply_with_oauth_error (
         hc->connection,
         MHD_HTTP_UNAUTHORIZED,
         "invalid_client",
@@ -352,7 +352,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
                         &bc->nonce))
   {
     GNUNET_break_op (0);
-    return TALER_MHD_reply_with_oauth_error (
+    return CH_reply_with_oauth_error (
       hc->connection,
       MHD_HTTP_UNAUTHORIZED,
       "invalid_grant",
@@ -396,7 +396,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
       return MHD_NO;
     case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
       GNUNET_break_op (0);
-      return TALER_MHD_reply_with_oauth_error (
+      return CH_reply_with_oauth_error (
         hc->connection,
         MHD_HTTP_UNAUTHORIZED,
         "invalid_grant",
@@ -411,6 +411,12 @@ CH_handler_token (struct CH_HandlerContext *hc,
     if (CHALLENGER_CM_UNKNOWN == code_challenge_method_enum)
     {
       GNUNET_break (0);
+      json_decref (address);
+      GNUNET_free (client_scope);
+      GNUNET_free (client_secret);
+      GNUNET_free (client_redirect_uri);
+      GNUNET_free (client_state);
+      GNUNET_free (code_challenge);
       return TALER_MHD_reply_with_error (
         hc->connection,
         MHD_HTTP_INTERNAL_SERVER_ERROR,
@@ -424,12 +430,13 @@ CH_handler_token (struct CH_HandlerContext *hc,
       if (NULL == bc->code_verifier)
       {
         GNUNET_break_op (0);
+        json_decref (address);
         GNUNET_free (client_scope);
         GNUNET_free (client_secret);
         GNUNET_free (client_redirect_uri);
         GNUNET_free (client_state);
         GNUNET_free (code_challenge);
-        return TALER_MHD_reply_with_oauth_error (
+        return CH_reply_with_oauth_error (
           hc->connection,
           MHD_HTTP_UNAUTHORIZED,
           "invalid_grant",
@@ -453,12 +460,13 @@ CH_handler_token (struct CH_HandlerContext *hc,
                             0))
           {
             GNUNET_break (0);
+            json_decref (address);
             GNUNET_free (client_scope);
             GNUNET_free (client_secret);
             GNUNET_free (client_redirect_uri);
             GNUNET_free (client_state);
             GNUNET_free (code_challenge);
-            return TALER_MHD_reply_with_oauth_error (
+            return CH_reply_with_oauth_error (
               hc->connection,
               MHD_HTTP_INTERNAL_SERVER_ERROR,
               "server_error",
@@ -485,12 +493,14 @@ CH_handler_token (struct CH_HandlerContext *hc,
                (NULL == encoded_hash) )
           {
             GNUNET_break (0);
+            json_decref (address);
             GNUNET_free (client_scope);
             GNUNET_free (client_secret);
             GNUNET_free (client_redirect_uri);
             GNUNET_free (client_state);
             GNUNET_free (code_challenge);
-            return TALER_MHD_reply_with_oauth_error (
+            GNUNET_free (encoded_hash);
+            return CH_reply_with_oauth_error (
               hc->connection,
               MHD_HTTP_INTERNAL_SERVER_ERROR,
               "server_error",
@@ -502,18 +512,21 @@ CH_handler_token (struct CH_HandlerContext *hc,
                            code_challenge))
           {
             GNUNET_break_op (0);
+            json_decref (address);
             GNUNET_free (client_scope);
             GNUNET_free (client_secret);
             GNUNET_free (client_redirect_uri);
             GNUNET_free (client_state);
             GNUNET_free (code_challenge);
-            return TALER_MHD_reply_with_oauth_error (
+            GNUNET_free (encoded_hash);
+            return CH_reply_with_oauth_error (
               hc->connection,
               MHD_HTTP_UNAUTHORIZED,
               "invalid_grant",
               TALER_EC_CHALLENGER_CLIENT_FORBIDDEN_BAD_CODE,
               "code_verifier does not match code_challenge (SHA256)");
           }
+          GNUNET_free (encoded_hash);
         }
         break;
       case CHALLENGER_CM_PLAIN:
@@ -522,12 +535,13 @@ CH_handler_token (struct CH_HandlerContext *hc,
                            code_challenge))
           {
             GNUNET_break_op (0);
+            json_decref (address);
             GNUNET_free (client_scope);
             GNUNET_free (client_secret);
             GNUNET_free (client_redirect_uri);
             GNUNET_free (client_state);
             GNUNET_free (code_challenge);
-            return TALER_MHD_reply_with_oauth_error (
+            return CH_reply_with_oauth_error (
               hc->connection,
               MHD_HTTP_UNAUTHORIZED,
               "invalid_grant",
@@ -539,12 +553,13 @@ CH_handler_token (struct CH_HandlerContext *hc,
       case CHALLENGER_CM_UNKNOWN:
       case CHALLENGER_CM_EMPTY:
         GNUNET_break (0);
+        json_decref (address);
         GNUNET_free (client_scope);
         GNUNET_free (client_secret);
         GNUNET_free (client_redirect_uri);
         GNUNET_free (client_state);
         GNUNET_free (code_challenge);
-        return TALER_MHD_reply_with_oauth_error (
+        return CH_reply_with_oauth_error (
           hc->connection,
           MHD_HTTP_INTERNAL_SERVER_ERROR,
           "server_error",
@@ -561,7 +576,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
       GNUNET_free (client_redirect_uri);
       GNUNET_free (client_state);
       GNUNET_free (code_challenge);
-      return TALER_MHD_reply_with_oauth_error (
+      return CH_reply_with_oauth_error (
         hc->connection,
         MHD_HTTP_CONFLICT,
         "invalid_request",
@@ -578,12 +593,13 @@ CH_handler_token (struct CH_HandlerContext *hc,
     GNUNET_free (client_secret);
     GNUNET_free (client_redirect_uri);
     GNUNET_free (client_state);
+    GNUNET_free (code_challenge);
     if (0 != strcmp (code,
                      bc->code))
     {
       GNUNET_break_op (0);
       GNUNET_free (code);
-      return TALER_MHD_reply_with_oauth_error (
+      return CH_reply_with_oauth_error (
         hc->connection,
         MHD_HTTP_UNAUTHORIZED,
         "invalid_grant",
@@ -622,7 +638,7 @@ CH_handler_token (struct CH_HandlerContext *hc,
       return MHD_NO;
     case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
       GNUNET_break (0);
-      return TALER_MHD_reply_with_oauth_error (
+      return CH_reply_with_oauth_error (
         hc->connection,
         MHD_HTTP_UNAUTHORIZED,
         "invalid_grant",
