@@ -5,7 +5,7 @@ set -eu
 
 if [ $# -ne 1 ]
 then
-    echo "Usage: $0 <phone_number>" 1>&2
+    echo "Usage: $0 '{\"CONTACT_PHONE\":\"+4112345678\"}'" 1>&2
     exit 1
 fi
 
@@ -13,7 +13,7 @@ SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
 SCRIPT_NAME=$(basename "$0")
 BASE="${SCRIPT_NAME%.sh}"
 
-PHONE_NUMBER="$1"
+PHONE_NUMBER=$(echo "$1" | jq -r .CONTACT_PHONE)
 MESSAGE=$(cat -)
 
 # List of sub-scripts to try.
@@ -22,7 +22,7 @@ PROVIDERS="telesign clicksend"
 for PROVIDER in $PROVIDERS
 do
     SCRIPT_PATH="$SCRIPT_DIR/${BASE}-${PROVIDER}.sh"
-    if [ -x "$SCRIPT" ]
+    if [ -x "$SCRIPT_PATH" ]
     then
 	if echo "$MESSAGE" | "$SCRIPT_PATH" "$PHONE_NUMBER"
 	then
