@@ -43,6 +43,7 @@
  * @param[out] auth_attempts_left set to number of attempts the user has left on this pin
  * @param[out] client_redirect_uri redirection URI of the client (for reporting failures)
  * @param[out] address_refused set to true if the address was refused (address change attempts exhausted)
+ * @param[out] solved set to true if the challenge is already solved
  * @return transaction status:
  *   #GNUNET_DB_STATUS_SUCCESS_ONE_RESULT if the address was changed
  *   #GNUNET_DB_STATUS_SUCCESS_NO_RESULTS if we do not permit further changes to the address (attempts exhausted)
@@ -60,6 +61,7 @@ CH_PG_challenge_set_address_and_pin (
   uint32_t *auth_attempts_left,
   bool *pin_transmit,
   char **client_redirect_uri,
-  bool *address_refused);
+  bool *address_refused,
+  bool *solved);
 
 #endif
