@@ -26,6 +26,7 @@
 #include "challenger_database_plugin.h"
 #include "challenger_database_lib.h"
 #include "pg_helper.h"
+#include "pg_address_get.h"
 #include "pg_client_add.h"
 #include "pg_client_modify.h"
 #include "pg_client_delete.h"
@@ -176,6 +177,7 @@ postgres_preflight (void *cls)
       return GNUNET_SYSERR;
     }
   }
+  GNUNET_PQ_reconnect_if_down (pg->conn);
   if (NULL == pg->transaction_name)
     return GNUNET_OK; /* all good */
   if (GNUNET_OK ==
@@ -388,6 +390,8 @@ libchallenger_plugin_db_postgres_init (void *cls)
     = &postgres_commit_transaction;
   plugin->rollback
     = &postgres_rollback;
+  plugin->address_get
+    = &CH_PG_address_get;
   plugin->client_add
     = &CH_PG_client_add;
   plugin->client_modify
